# Title

Brief Description of project

## Status


Version: ![version](https://img.shields.io/badge/version-0.1.0-blue)

[![Python](https://img.shields.io/badge/python-{python_version}-blue.svg)](https://www.python.org/downloads/)

[![License](https://img.shields.io/badge/license-MIT-green.svg)](LICENSE)

## Features

- [Feature 1]
- [Feature 2]
- [Feature 3]

## Installation

```bash
# Clone the repository
git clone repo_adress
# Change into the project directory
cd {project_name}
# Create and activate virtual environment
uv venv
source .venv/bin/activate
# Install the package
uv pip install -e .
```

## Project Structure
{project_name}/
├── src/
│ └── {project_name}/
├── tests/
├── docs/
└── examples/

## Versioning

This project uses [Semantic Versioning](https://semver.org/) and [Conventional Commits](https://www.conventionalcommits.org/).

To bump the version use commitizen:
https://commitizen-tools.github.io/commitizen/

```bash
cz bump
```
## Contributing

1. Fork the repository
2. Create your feature branch (`git checkout -b feature/amazing-feature`)
3. Commit your changes (`cz commit`)
4. Push to the branch (`git push origin feature/amazing-feature`)
5. Open a Pull Request

## Authors


Created by {author}
Email: {email}


## Dependencies

Requires Python {python_version} or greater

## License

This project is licensed under the MIT License - see the [LICENSE](LICENSE) file for details

## Acknowledgments

- Hat tip to anyone whose code was used
- Inspiration
- References
